@@ -1,9 +1,9 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 
 
-import os, glob, sys, gzip, re, traceback, string, commands
+import os, glob, sys, string
 
-from commands import getstatusoutput
+from subprocess import getstatusoutput
 
 from optparse import OptionParser
 
@@ -40,7 +40,7 @@ fs_options = {
 'auto': default_options
 }
 
-try_filesystems = ['vfat','msdos','iso9660','ntfs','auto']
+try_filesystems = ['vfat', 'msdos', 'iso9660', 'ntfs-3g', 'ntfs', 'auto']
 
 mount_command = '/bin/mount'
 umount_command = '/bin/umount'
@@ -59,28 +59,27 @@ mtab = '/etc/mtab'
 
 # end of default options
 
-VERSION='0.8'
+VERSION='0.8.1'
 
 if not os.path.isfile(config_file):
-    print "Missing configuration file", config_file
+    print ("Missing configuration file", config_file)
     sys.exit()
-    
-execfile(config_file)
 
+exec(open(config_file).read())
 
 #safety checks
 if ( not os.path.isabs(mntdir) or
      len(os.path.normpath(mntdir))<2  # empty or root /
      ):
-    print "mntdir is set to %s" % `mntdir`
-    print "This looks insane to me, refusing to continue"
-    print "Please edit /etc/mountpy.conf"
-    print "If you have no idea what this means, contact your system administrator."
-    print "If you have no idea what this means and YOU are "
-    print "an administrator, go read some basic literature about UNIX"
-    print "and then try again."
+    print("mntdir is set to", repr(mntdir))
+    print("This looks insane to me, refusing to continue")
+    print("Please edit /etc/mountpy.conf")
+    print("If you have no idea what this means, contact your system administrator.")
+    print("If you have no idea what this means and YOU are ")
+    print("an administrator, go read some basic literature about UNIX")
+    print("and then try again.")
     sys.exit()
-     
+
 colours = {
             'none'       :    "",
             'default'    :    "\033[0m",
@@ -161,7 +160,7 @@ def safe_rmdir(path):
         else:
             os.rmdir(path)
     else:
-        raise IOError, "Trying to remove suspicious directory: "+`path`
+        raise IOError("Trying to remove suspicious directory: "+repr(path))
 
 def get_all_devices(list_to_probe):
     r = []
@@ -173,7 +172,7 @@ def get_all_devices(list_to_probe):
             if x.startswith(device_prefix):
                 r.append(j)
             else:
-                alert("Discarding suspicious device "+`j`)
+                alert("Discarding suspicious device "+repr(j))
     return r
 
 def check_device(devicepath):
@@ -193,7 +192,7 @@ def is_removable(device):
     while len(drive)>=1 and drive[-1] in string.digits:
         del drive[-1]
     drive = ''.join(drive)
-    path = '/asys/block/%s/removable' % drive
+    path = '/sys/block/%s/removable' % drive
     try:
         val = file(path).read()
     except IOError:
@@ -226,6 +225,7 @@ def try_mount(devicepath, fs):
     d = {'uid':uid, 'gid':gid}
     mount_options = fs_options.get(fs, default_options) % d
     command = '%s "%s" "%s" -t %s -o %s' % (mount_command, devicepath, mountpoint, fs, mount_options)
+    verbose('Going to execute: '+command, 2)
     status, output = getstatusoutput(command)
     if status == 0:
         return True
@@ -268,7 +268,7 @@ def get_mounted_fs(mtab):
     devices = {}
     if os.path.exists(mtab):
         try:
-            lines = file(mtab).readlines()
+            lines = open(mtab).readlines()
             devices = [x.split()[0:2] for x in lines]
             devices = dict(devices)
         except IOError:
@@ -354,7 +354,7 @@ euid = os.geteuid()
 
 # test if we are running with sudo
 if uid==0:
-    if os.environ.has_key('SUDO_UID'):
+    if 'SUDO_UID' in os.environ:
         uid = int(os.environ['SUDO_UID'])
         verbose("sudo detected")
 
@@ -416,13 +416,13 @@ for devicepath in devices:
             processed.append(devicepath)
         if r==False:
             unsuccessful.append(devicepath)
-            
+
 if options.action == "mount": 
     if processed:
         info('List of mounted devices: ', ' '.join(processed))
     else:
         info('Found nothing to mount')
-    
+
 if options.action == "umount":
     if processed:
         info('List of umounted devices: ', ' '.join(processed))
